@@ -5,11 +5,11 @@ use IO::Socket;
 
 sub start_server
 {
-    my $S = shift;
+    my ($S, @args) = @_;
 
     my $pid;
 
-    if (! defined($pid = fork()))
+    if (! defined($pid = fork))
     {
         die "fork() error: $!, stopped";
     }
@@ -19,37 +19,43 @@ sub start_server
     }
     else
     {
-        $S->server_loop(@_);
+        $S->server_loop(@args);
         exit; # When the parent stops this server, we want to stop this child
     }
 }
 
 sub stop_server
 {
-    my $pid = shift;
+    my ($pid, $no_sleep) = @_;
 
     # Per RT 27778, use 'KILL' instead of 'INT' as the stop-server signal for
     # MSWin platforms:
-    my $SIGNAL = ($^O eq "MSWin32") ? 'KILL' : 'INT';
+    my $SIGNAL = ($^O eq 'MSWin32') ? 'KILL' : 'INT';
     kill $SIGNAL, $pid;
-    sleep 2; # give the old sockets time to go away 
+    if (! $no_sleep)
+    {
+        sleep 2; # give the old sockets time to go away
+    }
+
+    return;
 }
 
 sub find_port
 {
-    my $start_at = $_[0] || 9000;
+    my $start_at = shift;
+    $start_at ||= 9000;
 
-    my ($port, $sock);
-
-    for ($port = $start_at; $port < ($start_at + 1000); $port++)
+    for my $port ($start_at .. ($start_at + 2000))
     {
-        $sock = IO::Socket->new(Domain   => AF_INET,
-                                PeerAddr => 'localhost',
-                                PeerPort => $port);
-        return $port unless ref $sock;
+        my $sock = IO::Socket->new(
+            Domain   => AF_INET,
+            PeerAddr => 'localhost',
+            PeerPort => $port
+        );
+        return $port if (! ref $sock);
     }
 
-    -1;
+    return -1;
 }
 
 1;
